@@ -92,8 +92,7 @@ Then, for fancier things below, note that:
 
 import collections
 from collections import OrderedDict
-# noinspection PyProtectedMember
-from enum import EnumMeta, Enum, _EnumDict
+from enum import EnumMeta, Enum
 import itertools
 from typing import Any, List, Optional, Tuple, Type
 
@@ -143,6 +142,130 @@ class StrEnum(Enum):
         return str(self) < str(other)
 
 
+# -----------------------------------------------------------------------------
+# EnumDict and support functions from Python 3.6
+# -----------------------------------------------------------------------------
+
+_auto_null = object()
+
+
+class _Auto:
+    """
+    Instances are replaced with an appropriate value in Enum class suites.
+    """
+    value = _auto_null
+
+
+def _is_descriptor(obj):
+    """
+    A copy of enum._is_descriptor from Python 3.6.
+
+    Returns True if obj is a descriptor, False otherwise.
+    """
+    return (
+            hasattr(obj, '__get__') or
+            hasattr(obj, '__set__') or
+            hasattr(obj, '__delete__'))
+
+
+def _is_dunder(name):
+    """
+    A copy of enum._is_dunder from Python 3.6.
+
+    Returns True if a __dunder__ name, False otherwise.
+    """
+    return (len(name) > 4 and
+            name[:2] == name[-2:] == '__' and
+            name[2] != '_' and
+            name[-3] != '_')
+
+
+def _is_sunder(name):
+    """
+    A copy of enum._is_sunder from Python 3.6.
+
+    Returns True if a _sunder_ name, False otherwise.
+    """
+    return (len(name) > 2 and
+            name[0] == name[-1] == '_' and
+            name[1:2] != '_' and
+            name[-2:-1] != '_')
+
+
+class EnumDict(dict):
+    """
+    A copy of enum._EnumDict from Python 3.6 that we are allowed to access and
+    doesn't vanish in Python 3.9.
+
+    Track enum member order and ensure member names are not reused.
+
+    EnumMeta will use the names found in self._member_names as the
+    enumeration member names.
+    """
+    def __init__(self):
+        super().__init__()
+        self._member_names = []
+        self._last_values = []
+        self._ignore = []
+        self._auto_called = False
+
+    def __setitem__(self, key, value):
+        """Changes anything not dundered or not a descriptor.
+
+        If an enum member name is used twice, an error is raised; duplicate
+        values are not checked for.
+
+        Single underscore (sunder) names are reserved.
+
+        """
+        if _is_sunder(key):
+            if key not in (
+                    '_order_', '_create_pseudo_member_',
+                    '_generate_next_value_', '_missing_', '_ignore_',
+                    ):
+                raise ValueError('_names_ are reserved for future Enum use')
+            if key == '_generate_next_value_':
+                # check if members already defined as auto()
+                if self._auto_called:
+                    raise TypeError(
+                        "_generate_next_value_ must be defined before members")
+                setattr(self, '_generate_next_value', value)
+            elif key == '_ignore_':
+                if isinstance(value, str):
+                    value = value.replace(',',' ').split()
+                else:
+                    value = list(value)
+                self._ignore = value
+                already = set(value) & set(self._member_names)
+                if already:
+                    raise ValueError(
+                        '_ignore_ cannot specify already set names: %r' %
+                        (already, )
+                    )
+        elif _is_dunder(key):
+            if key == '__order__':
+                key = '_order_'
+        elif key in self._member_names:
+            # descriptor overwriting an enum?
+            raise TypeError('Attempted to reuse key: %r' % key)
+        elif key in self._ignore:
+            pass
+        elif not _is_descriptor(value):
+            if key in self:
+                # enum overwriting a descriptor?
+                raise TypeError('%r already defined as: %r' % (key, self[key]))
+            if isinstance(value, _Auto):
+                self._auto_called = True
+                if value.value == _auto_null:
+                    # noinspection PyUnresolvedReferences
+                    value.value = self._generate_next_value(
+                        key, 1, len(self._member_names), self._last_values[:])
+                value = value.value
+            self._member_names.append(key)
+            self._last_values.append(value)
+        super().__setitem__(key, value)
+
+
 # -----------------------------------------------------------------------------
 # AutoStrEnum
 # -----------------------------------------------------------------------------
@@ -154,7 +277,7 @@ class AutoStrEnumMeta(EnumMeta):
         Scan through ``oldclassdict`` and convert any value that is a plain
         tuple into a ``str`` of the name instead.
         """
-        newclassdict = _EnumDict()
+        newclassdict = EnumDict()
         for k, v in oldclassdict.items():
             if v == ():
                 v = k
@@ -200,7 +323,7 @@ class LowerCaseAutoStrEnumMeta(EnumMeta):
         Scan through ``oldclassdict`` and convert any value that is a plain
         tuple into a ``str`` of the name instead.
         """
-        newclassdict = _EnumDict()
+        newclassdict = EnumDict()
         for k, v in oldclassdict.items():
             if v == ():
                 v = k.lower()
@@ -305,7 +428,7 @@ class AutoNumberObjectMetaClass(type):
 class AutoNumberObject(metaclass=AutoNumberObjectMetaClass):
     """
     From comment by Duncan Booth at
-    http://www.acooke.org/cute/Pythonssad0.html, with trivial rename.
+    https://www.acooke.org/cute/Pythonssad0.html, with trivial rename.
 
     Usage:
 
@@ -522,18 +645,12 @@ class CaseInsensitiveEnumMeta(EnumMeta):
             greenapple = 2
             PineApple = 3
             
-        >>> TestEnum["REDAPPLE"]
-        <TestEnum.REDAPPLE: 1>
-        >>> TestEnum["redapple"]
-        <TestEnum.REDAPPLE: 1>
-        >>> TestEnum["greenapple"]
-        <TestEnum.greenapple: 2>
-        >>> TestEnum["greenappLE"]
-        <TestEnum.greenapple: 2>
-        >>> TestEnum["PineApple"]
-        <TestEnum.PineApple: 3>
-        >>> TestEnum["PineApplE"]
-        <TestEnum.PineApple: 3>
+        TestEnum["REDAPPLE"]  # <TestEnum.REDAPPLE: 1>
+        TestEnum["redapple"]  # <TestEnum.REDAPPLE: 1>
+        TestEnum["greenapple"]  # <TestEnum.greenapple: 2>
+        TestEnum["greenappLE"]  # <TestEnum.greenapple: 2>
+        TestEnum["PineApple"]  # <TestEnum.PineApple: 3>
+        TestEnum["PineApplE"]  # <TestEnum.PineApple: 3>
 
     """  # noqa
     def __getitem__(self, item: Any) -> Any:
