@@ -12,7 +12,7 @@
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0
+        https://www.apache.org/licenses/LICENSE-2.0
 
     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
@@ -120,7 +120,7 @@ class SqlaColumnInspectionInfo(object):
             sqla_info_dict:
                 see
         
-                - http://docs.sqlalchemy.org/en/latest/core/reflection.html#sqlalchemy.engine.reflection.Inspector.get_columns
+                - https://docs.sqlalchemy.org/en/latest/core/reflection.html#sqlalchemy.engine.reflection.Inspector.get_columns
                 - https://bitbucket.org/zzzeek/sqlalchemy/issues/4051/sqlalchemyenginereflectioninspectorget_col
         """  # noqa
         # log.debug(repr(sqla_info_dict))
@@ -240,7 +240,7 @@ def get_single_int_autoincrement_colname(table_: Table) -> Optional[str]:
                              'IsIdentity') = 1
         ORDER BY table_name;
 
-      ... http://stackoverflow.com/questions/87747
+      ... https://stackoverflow.com/questions/87747
 
     - Also:
 
@@ -550,7 +550,7 @@ def make_bigint_autoincrement_column(column_name: str,
         raise AssertionError(
             f"SQLAlchemy doesn't support non-PK autoincrement fields yet for "
             f"dialect {dialect.name!r}")
-        # see http://stackoverflow.com/questions/2937229
+        # see https://stackoverflow.com/questions/2937229
 
 
 def column_creation_ddl(sqla_column: Column, dialect: Dialect) -> str:
@@ -914,11 +914,11 @@ def convert_sqla_type_for_dialect(
     if is_mssql_timestamp and to_mssql and convert_mssql_timestamp:
         # You cannot write explicitly to a TIMESTAMP field in SQL Server; it's
         # used for autogenerated values only.
-        # - http://stackoverflow.com/questions/10262426/sql-server-cannot-insert-an-explicit-value-into-a-timestamp-column  # noqa
+        # - https://stackoverflow.com/questions/10262426/sql-server-cannot-insert-an-explicit-value-into-a-timestamp-column  # noqa
         # - https://social.msdn.microsoft.com/Forums/sqlserver/en-US/5167204b-ef32-4662-8e01-00c9f0f362c2/how-to-tranfer-a-column-with-timestamp-datatype?forum=transactsql  # noqa
         #   ... suggesting BINARY(8) to store the value.
         # MySQL is more helpful:
-        # - http://stackoverflow.com/questions/409286/should-i-use-field-datetime-or-timestamp  # noqa
+        # - https://stackoverflow.com/questions/409286/should-i-use-field-datetime-or-timestamp  # noqa
         return mssql.base.BINARY(8)
 
     # -------------------------------------------------------------------------
@@ -1053,7 +1053,7 @@ def does_sqlatype_require_index_len(
 
     (MySQL, at least, requires index length to be specified for ``BLOB`` and
     ``TEXT`` columns:
-    http://dev.mysql.com/doc/refman/5.7/en/create-index.html.)
+    https://dev.mysql.com/doc/refman/5.7/en/create-index.html.)
     """
     coltype = _coltype_to_typeengine(coltype)
     if isinstance(coltype, sqltypes.Text):
@@ -1083,7 +1083,7 @@ def hack_in_mssql_xml_type():
     """  # noqa
     log.debug("Adding type 'xml' to SQLAlchemy reflection for dialect 'mssql'")
     mssql.base.ischema_names['xml'] = mssql.base.TEXT
-    # http://stackoverflow.com/questions/32917867/sqlalchemy-making-schema-reflection-find-use-a-custom-type-for-all-instances  # noqa
+    # https://stackoverflow.com/questions/32917867/sqlalchemy-making-schema-reflection-find-use-a-custom-type-for-all-instances  # noqa
 
     # print(repr(mssql.base.ischema_names.keys()))
     # print(repr(mssql.base.ischema_names))
@@ -1098,7 +1098,7 @@ def column_types_equal(a_coltype: TypeEngine, b_coltype: TypeEngine) -> bool:
     Checks that two SQLAlchemy column types are equal (by comparing ``str()``
     versions of them).
     
-    See http://stackoverflow.com/questions/34787794/sqlalchemy-column-type-comparison.
+    See https://stackoverflow.com/questions/34787794/sqlalchemy-column-type-comparison.
     
     IMPERFECT. 
     """  # noqa
